summaryrefslogtreecommitdiff
path: root/redis/client.py
diff options
context:
space:
mode:
Diffstat (limited to 'redis/client.py')
-rwxr-xr-xredis/client.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/redis/client.py b/redis/client.py
index 9b0086b..d82078e 100755
--- a/redis/client.py
+++ b/redis/client.py
@@ -841,27 +841,27 @@ class StrictRedis(object):
"Echo the string back from the server"
return self.execute_command('ECHO', value)
- def flushall(self, sync=True):
+ def flushall(self, asynchronous=False):
"""
Delete all keys in all databases on the current host.
- ``sync`` indicates whether the operation is executed
- synchronously by the server.
+ ``asynchronous`` indicates whether the operation is
+ executed asynchronously by the server.
"""
args = []
- if not sync:
+ if not asynchronous:
args.append(Token.get_token('ASYNC'))
return self.execute_command('FLUSHALL', *args)
- def flushdb(self, sync=True):
+ def flushdb(self, asynchronous=False):
"""
Delete all keys in the current database.
- ``sync`` indicates whether the operation is executed
- synchronously by the server.
+ ``asynchronous`` indicates whether the operation is
+ executed asynchronously by the server.
"""
args = []
- if not sync:
+ if not asynchronous:
args.append(Token.get_token('ASYNC'))
return self.execute_command('FLUSHDB', *args)